@@ -87,10 +87,13 @@ def send_sms():
 
     telma = (msisdn[-9:]).startswith("34")
 
-    if telma:
+    smpp = json_doc.get('sender_id')
+    if smpp == "mfs":
+        sender_id = "mfs"
+    elif telma:
         LOGS.logger.info("MSISDN Telma redirected to Orange SMPP.")
         sender_id = "orange"
-    elif not telma and json_doc.get('sender_id') == 'orange':
+    elif not telma and smpp == 'orange':
         LOGS.logger.warning(
             "MSISDN '{}' is not Telma but targeting Orange SMPP. "
             "Redirected to default SMPP."
